<?php

namespace Moscow\RUSComing\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moscow\RUSComing\Http\Requests\IndexRequest;
use Moscow\RUSComing\Interfaces\IndexRepositoryInterface;
use Moscow\RUSComing\Models\Index;
use Moscow\RUSComing\Forms\Index as Form;

/**
 * APIController  class for index.
 */
class IndexAPIController extends BaseController
{

    /**
     * Initialize index resource controller.
     *
     * @param type IndexRepositoryInterface $index
     *
     * @return null
     */
    public function __construct(IndexRepositoryInterface $index)
    {
        parent::__construct();
        $this->repository = $index;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moscow\RUSComing\Repositories\Criteria\IndexResourceCriteria::class);
    }

    /**
     * Display a list of index.
     *
     * @return Response
     */
    public function index(IndexRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moscow\RUSComing\Repositories\Presenter\IndexPresenter::class)
            ->paginate();
    }

    /**
     * Display index.
     *
     * @param Request $request
     * @param Model   $index
     *
     * @return Response
     */
    public function show(IndexRequest $request, Index $index)
    {
        return $index->setPresenter(\Moscow\RUSComing\Repositories\Presenter\IndexListPresenter::class);
        ;
    }

    /**
     * Create new index.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IndexRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('r_u_s-coming::index.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('r_u_s-coming/index/' . $index->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('r_u_s-coming/index');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the index.
     *
     * @param Request $request
     * @param Model   $index
     *
     * @return Response
     */
    public function update(IndexRequest $request, Index $index)
    {
        try {
            $data = $request->all();

            $index->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('r_u_s-coming::index.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('r_u_s-coming/index/' . $index->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('r_u_s-coming/index/' . $index->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the index.
     *
     * @param Model   $index
     *
     * @return Response
     */
    public function destroy(IndexRequest $request, Index $index)
    {
        try {
            $index->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('r_u_s-coming::index.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('r_u_s-coming/index/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('r_u_s-coming/index/' . $index->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
