<?php

namespace Moscow\RUSComing\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Moscow\RUSComing\Http\Requests\IndexRequest;
use Moscow\RUSComing\Models\Index;

/**
 * Admin web controller class.
 */
class IndexWorkflowController extends BaseController
{

    /**
     * Workflow controller function for index.
     *
     * @param Model   $index
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(IndexRequest $request, Index $index, $step)
    {

        try {

            $index->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('r_u_s-coming::index.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/index/index/' . $index->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/index/index/' . $index->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for index.
     *
     * @param Model   $index
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Index $index, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $index->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('r_u_s-coming::index.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('r_u_s-coming::admin.index.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('r_u_s-coming::admin.index.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('r_u_s-coming::admin.index.message', $data)->render();

        }

    }
}
