<?php

namespace Moscow\RUSComing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moscow\RUSComing\Models\Index;

class IndexPolicy
{

    /**
     * Determine if the given user can view the index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function view(UserPolicy $user, Index $index)
    {
        if ($user->canDo('r_u_s-coming.index.view') && $user->isAdmin()) {
            return true;
        }

        return $index->user_id == user_id() && $index->user_type == user_type();
    }

    /**
     * Determine if the given user can create a index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('r_u_s-coming.index.create');
    }

    /**
     * Determine if the given user can update the given index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function update(UserPolicy $user, Index $index)
    {
        if ($user->canDo('r_u_s-coming.index.edit') && $user->isAdmin()) {
            return true;
        }

        return $index->user_id == user_id() && $index->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Index $index)
    {
        return $index->user_id == user_id() && $index->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Index $index)
    {
        if ($user->canDo('r_u_s-coming.index.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given index.
     *
     * @param UserPolicy $user
     * @param Index $index
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Index $index)
    {
        if ($user->canDo('r_u_s-coming.index.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
