<?php

namespace Moscow\RUSComing\Providers;

use Illuminate\Support\ServiceProvider;

class RUSComingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'r_u_s-coming');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'r_u_s-coming');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerRUSComing();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerRUSComing()
    {
        $this->app->bind('r_u_s-coming', function($app) {
            return new RUSComing($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('RUSComing', 'Lavalite\RUSComing\Facades\RUSComing');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moscow.r_u_s-coming', function ($app) {
            return $this->app->make('Moscow\RUSComing\RUSComing');
        });

                // Bind Index to repository
        $this->app->bind(
            'Moscow\RUSComing\Interfaces\IndexRepositoryInterface',
            \Moscow\RUSComing\Repositories\Eloquent\IndexRepository::class
        );

        $this->app->register(\Moscow\RUSComing\Providers\AuthServiceProvider::class);
                $this->app->register(\Moscow\RUSComing\Providers\EventServiceProvider::class);
        
        $this->app->register(\Moscow\RUSComing\Providers\RouteServiceProvider::class);
                // $this->app->register(\Moscow\RUSComing\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and r_u_s-coming's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moscow.r_u_s-coming'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeRUSComing::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moscow.r_u_s-coming'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moscow/r_u_s-coming.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/r_u_s-coming')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/r_u_s-coming')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
